/**
 * Shared utilities for CLAUDE.md template generation
 * Reduces code duplication between install and init commands
 */
export interface TemplateVariables {
    projectName?: string;
    language?: string;
    framework?: string;
    architecture?: string;
    testFramework?: string;
    buildSystem?: string;
    commands?: {
        install: string;
        test: string;
        build: string;
        dev: string;
    };
}
/**
 * Generate the AIT³ workflow section (common to both templates)
 */
export declare function generateAit3WorkflowSection(): string;
/**
 * Generate architecture section
 */
export declare function generateArchitectureSection(vars: TemplateVariables): string;
/**
 * Generate key commands section
 */
export declare function generateKeyCommandsSection(vars: TemplateVariables): string;
/**
 * Generate Claude Code actions section
 */
export declare function generateClaudeCodeActionsSection(vars: TemplateVariables): string;
/**
 * Generate basic template structure (for install command)
 */
export declare function generateBasicTemplate(vars?: TemplateVariables): string;
/**
 * Generate comprehensive template (for init command)
 */
export declare function generateComprehensiveTemplate(vars: TemplateVariables): string;
/**
 * Add Docker section if Docker is detected
 */
export declare function generateDockerSection(hasDockerfile: boolean, composeFile?: string): string;
/**
 * Generate AI development guidelines section
 */
export declare function generateAiGuidelinesSection(): string;
