import type { TicketService } from '../services/interfaces/TicketService.js';
import type { GitService } from '../services/interfaces/GitService.js';
import type { ProjectAnalyzer } from '../services/interfaces/ProjectAnalyzer.js';
export interface Ticket {
    id: string;
    title: string;
    status: 'todo' | 'doing' | 'done';
    priority: 'low' | 'medium' | 'high' | 'critical';
    created: string;
    updated: string;
    started?: string;
    completed?: string;
    assignee?: string;
    labels: string[];
    description?: string;
}
export interface CreateTicketOptions {
    priority?: 'low' | 'medium' | 'high' | 'critical';
    assignee?: string;
    labels?: string[];
    status?: 'todo' | 'doing' | 'done';
}
export interface TicketConfig {
    backend: string;
    path: string;
    numbering: {
        format: string;
        increment: number;
        next: number;
    };
    templates: Record<string, string>;
    labels: {
        priority: string[];
        type: string[];
        status: string[];
    };
}
export interface CLIResult {
    success: boolean;
    message: string;
    data?: any;
    exitCode?: number;
}
export interface CreateTicketArgs {
    title: string;
    priority?: 'low' | 'medium' | 'high' | 'critical';
    assignee?: string;
    labels?: string[];
}
export interface Services {
    ticketService: TicketService;
    gitService?: GitService;
    projectAnalyzer?: ProjectAnalyzer;
}
export interface ListTicketsArgs {
    status?: 'todo' | 'doing' | 'done';
    priority?: 'low' | 'medium' | 'high' | 'critical';
    assignee?: string;
}
export interface ShowTicketArgs {
    id: string;
}
export interface StartTicketArgs {
    id: string;
}
export interface CompleteTicketArgs {
    id: string;
}
export interface UndoTicketArgs {
    id: string;
    dryRun?: boolean;
}
