import type { Services } from '../common/types.js';
/**
 * ServiceFactory provides dependency injection for all services
 * This ensures commands depend on interfaces, not implementations
 */
export declare class ServiceFactory {
    /**
     * Create default services for production use
     */
    static createServices(): Services;
    /**
     * Create services for test environments
     * Disables Git operations to avoid conflicts
     */
    static createTestServices(ticketsPath: string): Services;
    /**
     * Create GitService instance
     * Returns undefined in test environments
     */
    private static createGitService;
    /**
     * Create TicketService instance
     */
    private static createTicketService;
    /**
     * Create ProjectAnalyzer instance
     */
    private static createProjectAnalyzer;
}
