export declare const orchestratorTemplate = "# Orchestrator\n\nSplit complex tasks into sequential steps, where each step can contain multiple parallel subtasks.\n\n## Process\n\n1. **Initial Analysis**\n   - First, analyze the entire task to understand scope and requirements\n   - Identify dependencies and execution order\n   - Plan sequential steps based on dependencies\n\n2. **Step Planning**\n   - Break down into 2-4 sequential steps\n   - Each step can contain multiple parallel subtasks\n   - Define what context from previous steps is needed\n\n3. **Step-by-Step Execution**\n   - Execute all subtasks within a step in parallel\n   - Wait for all subtasks in current step to complete\n   - Pass relevant results to next step\n   - Request concise summaries (100-200 words) from each subtask\n\n4. **Step Review and Adaptation**\n   - After each step completion, review results\n   - Validate if remaining steps are still appropriate\n   - Adjust next steps based on discoveries\n   - Add, remove, or modify subtasks as needed\n\n5. **Progressive Aggregation**\n   - Synthesize results from completed step\n   - Use synthesized results as context for next step\n   - Build comprehensive understanding progressively\n   - Maintain flexibility to adapt plan\n\n## Example Usage\n\nWhen given \"analyze test lint and commit\":\n\n**Step 1: Initial Analysis** (1 subtask)\n- Analyze project structure to understand test/lint setup\n\n**Step 2: Quality Checks** (parallel subtasks)\n- Run tests and capture results\n- Run linting and type checking\n- Check git status and changes\n\n**Step 3: Fix Issues** (parallel subtasks, using Step 2 results)\n- Fix linting errors found in Step 2\n- Fix type errors found in Step 2\n- Prepare commit message based on changes\n*Review: If no errors found in Step 2, skip fixes and proceed to commit*\n\n**Step 4: Final Validation** (parallel subtasks)\n- Re-run tests to ensure fixes work\n- Re-run lint to verify all issues resolved\n- Create commit with verified changes\n*Review: If Step 3 had no fixes, simplify to just creating commit*\n\n## Key Benefits\n\n- **Sequential Logic**: Steps execute in order, allowing later steps to use earlier results\n- **Parallel Efficiency**: Within each step, independent tasks run simultaneously\n- **Memory Optimization**: Each subtask gets minimal context, preventing overflow\n- **Progressive Understanding**: Build knowledge incrementally across steps\n- **Clear Dependencies**: Explicit flow from analysis \u2192 execution \u2192 validation\n\n## Implementation Notes\n\n- Always start with a single analysis task to understand the full scope\n- Group related parallel tasks within the same step\n- Pass only essential findings between steps (summaries, not full output)\n- Use TodoWrite to track both steps and subtasks for visibility\n- After each step, explicitly reconsider the plan:\n  - Are the next steps still relevant?\n  - Did we discover something that requires new tasks?\n  - Can we skip or simplify upcoming steps?\n  - Should we add new validation steps?\n\n## Adaptive Planning Example\n\n```\nInitial Plan: Step 1 \u2192 Step 2 \u2192 Step 3 \u2192 Step 4\n\nAfter Step 2: \"No errors found in tests or linting\"\nAdapted Plan: Step 1 \u2192 Step 2 \u2192 Skip Step 3 \u2192 Simplified Step 4 (just commit)\n\nAfter Step 2: \"Found critical architectural issue\"\nAdapted Plan: Step 1 \u2192 Step 2 \u2192 New Step 2.5 (analyze architecture) \u2192 Modified Step 3\n```\n";
